##########
Key class
##########

.. currentmodule:: ddbmock.database.key

.. autoclass:: Key

Constructors
============

__init__
--------

.. automethod:: Key.__init__

from_dict
---------

.. automethod:: Key.from_dict

Key manipulations
=================

read
----

.. automethod:: Key.read

to_dict
-------

.. automethod:: Key.to_dict

PrimaryKey
==========

.. autoclass:: PrimaryKey
